import React from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var ITBem;
(function (ITBem) {
    ITBem["DEFAULT"] = "-";
    ITBem["MODIFIER"] = "--";
    ITBem["BLOCK"] = "";
    ITBem["CHILD"] = "_";
})(ITBem || (ITBem = {}));
var BEM = /** @class */ (function () {
    function BEM(parent, classNames) {
        this._listClassNames = [];
        this._parent = parent;
        this._classNames = classNames;
        this._listClassNames.push(parent);
    }
    BEM.prototype.toString = function () {
        var _this = this;
        return Object.entries(this._classNames).reduce(function (previousValue, currentValue) {
            if (currentValue[1]) {
                if (typeof currentValue[1] == "string") {
                    previousValue.push(_this._parent + ITBem.MODIFIER + currentValue[0] + ITBem.DEFAULT + currentValue[1]);
                }
                else if (typeof currentValue[1] == "boolean") {
                    previousValue.push(_this._parent + ITBem.MODIFIER + currentValue[0]);
                }
            }
            return previousValue;
        }, __spreadArrays(this._listClassNames)).join(" ");
    };
    BEM.prototype.Append = function (className) {
        if (!className)
            return this;
        this._listClassNames.push(className);
        return this;
    };
    BEM.prototype.Children = function (name, extra) {
        if (extra === void 0) { extra = ""; }
        return this._parent + "__" + name + (extra ? " " + extra : '');
    };
    BEM.prototype.Modifier = function (children, modifier, active, extra) {
        if (extra === void 0) { extra = ""; }
        var data = [this._parent + "__" + children];
        if (active) {
            data.push(this._parent + "__" + children + "--" + modifier);
        }
        if (extra) {
            data.push(extra);
        }
        return data.join(" ");
    };
    return BEM;
}());

// Generated with util/create-component.js
var Badge = function (_a) {
    var _b;
    var colorText = _a.colorText, style = _a.style, variant = _a.variant, className = _a.className, children = _a.children, color = _a.color;
    var bem = new BEM("Badge", (_b = {},
        _b[color] = variant == "outline" && !!color,
        _b.bg = variant == "solid" && color,
        _b[variant] = !!variant,
        _b[colorText] = !!colorText,
        _b));
    bem.Append(className);
    return (React.createElement("span", { style: style, className: bem.toString() }, children));
};

// Generated with util/create-component.js
var Divider = function (_a) {
    var _b;
    var className = _a.className, orientation = _a.orientation, style = _a.style;
    var bem = new BEM("Divider", (_b = {},
        _b[orientation] = !!orientation,
        _b));
    bem.Append(className);
    return (React.createElement("div", { style: style, className: bem.toString() },
        React.createElement("hr", null)));
};

var List = function (_a) {
    var className = _a.className, _b = _a.isOrder, isOrder = _b === void 0 ? false : _b, rest = __rest(_a, ["className", "isOrder"]);
    var bem = new BEM("List", {});
    bem.Append(className);
    var TagComponent = isOrder ? OrderedList : UnorderedList;
    return (React.createElement(TagComponent, __assign({}, rest, { className: bem.toString() })));
};

// Generated with util/create-component.js
var ListItem = function (_a) {
    var className = _a.className, style = _a.style, children = _a.children;
    var bem = new BEM("ListItem", {});
    bem.Append(className);
    return (React.createElement("li", { style: style, className: bem.toString() }, children));
};

var OrderedList = function (_a) {
    var className = _a.className, style = _a.style, children = _a.children, rows = _a.rows;
    var bem = new BEM("OrderedList", {});
    bem.Append(className);
    return (React.createElement("ol", { style: style, className: bem.toString() },
        rows && rows.map(function (row, index) { return (React.createElement(ListItem, __assign({ key: index }, row))); }),
        children));
};

var UnorderedList = function (_a) {
    var className = _a.className, style = _a.style, children = _a.children, rows = _a.rows;
    var bem = new BEM("UnorderedList", {});
    bem.Append(className);
    return (React.createElement("ul", { style: style, className: bem.toString() },
        rows && rows.map(function (row, index) { return (React.createElement(ListItem, __assign({ key: index }, row))); }),
        children));
};

export { Badge, Divider, List, ListItem, OrderedList, UnorderedList };
//# sourceMappingURL=index.esm.js.map
